@@ -588,7 +588,7 @@ class UserConfiguration(Configuration):
         self.config_name = config or '.' + os.path.splitext(sys.argv[0])[0]
         self.default_config_file = os.path.join('~', self.config_name)
         self.default_config_file_path = os.path.expanduser(self.default_config_file)
-        if os.path.exists(self.default_config_file_path)
+        if os.path.exists(self.default_config_file_path):
             self.load_help += ' [DEFAULT: %s]' % default_config_file
 
         Configuration.__init__(self, usage=self.usage, load=load)
